C$Procedure      GETXYZ ( Voxel index to coordinates )
 
      SUBROUTINE GETXYZ ( IXYZ, NVOX, VIXYZ )
 
C$ Abstract
C
C     Given a voxel's index value, return its integral voxel
C     grid coordinates.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     voxel index
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               IXYZ
      INTEGER               NVOX   ( 3 )
      INTEGER               VIXYZ  ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IXYZ       I   Voxel index.
C     NVOX       I   Dimensions of voxel grid.
C     VIXYZ      O   Integral voxel coordinates.
C
C$ Detailed_Input
C
C     IXYZ       Voxel index; lies in the range 1 to
C                NVOX(1)*NVOX(2)*NVOX(3).
C
C     NVOX       Dimensions of voxel grid in X, Y and Z directions.
C
C$ Detailed_Output
C
C     VIXYZ      Integral coordinates of the voxel; values lie in
C                the ranges (1 to NVOX(1), 1 to NVOX(2), 1 to NVPX(3)).
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C     1)
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     voxel index to coordinates
C
C-&
 
 
      INTEGER               IX
      INTEGER               IY
      INTEGER               IZ
      INTEGER               NX
      INTEGER               NY
      INTEGER               IXY
      INTEGER               NXNY
 
      LOGICAL               RETURN
      LOGICAL               FIRST
 
      SAVE                  NX
      SAVE                  NY
      SAVE                  FIRST
      SAVE                  NXNY
 
      DATA     FIRST   / .TRUE. /
 
C
C     Standard SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'GETXYZ' )
 
C
C     Compute and save constants.
C
 
      IF ( FIRST ) THEN
         NX    = NVOX(1)
         NY    = NVOX(2)
         NXNY  = NX*NY
         FIRST = .FALSE.
      END IF
 
      IZ  = INT ( IXYZ / NXNY )
      IXY = MOD ( IXYZ, NXNY )
 
      IF ( IXY .GT. 0 ) THEN
         IZ = IZ + 1
      ELSE
         IXY = NXNY
      END IF
 
      IY = 1 + INT ( IXY / NX )
      IX = MOD ( IXY, NX )
 
      IF ( IX .EQ. 0 ) THEN
         IX = NX
         IY = IY - 1
      END IF
 
      VIXYZ(1) = IX
      VIXYZ(2) = IY
      VIXYZ(3) = IZ
 
C
C     Standard SPICELIB error handling.
C
 
      CALL CHKOUT ( 'GETXYZ' )
 
      RETURN
      END
